@@ -9,7 +9,7 @@
 #' @param size.range the minimum and maximum size of members of each term in consideration. By default, it sets to a minimum of 10 but no more than 2000
 #' @param min.overlap the minimum number of overlaps. Only those terms with members that overlap with input data at least min.overlap (3 by default) will be processed
 #' @param which.distance which terms with the distance away from the ontology root (if any) is used to restrict terms in consideration. By default, it sets to 'NULL' to consider all distances
-#' @param test the statistic test used. It can be "fisher" for using fisher's exact test, "hypergeo" for using hypergeometric test, or "binomial" for using binomial test. Fisher's exact test is to test the independence between gene group (genes belonging to a group or not) and gene annotation (genes annotated by a term or not), and thus compare sampling to the left part of background (after sampling without replacement). Hypergeometric test is to sample at random (without replacement) from the background containing annotated and non-annotated genes, and thus compare sampling to background. Unlike hypergeometric test, binomial test is to sample at random (with replacement) from the background with the constant probability. In terms of the ease of finding the significance, they are in order: hypergeometric test > binomial test > fisher's exact test. In other words, in terms of the calculated p-value, hypergeometric test < binomial test < fisher's exact test
+#' @param test the test statistic used. It can be "fisher" for using fisher's exact test, "hypergeo" for using hypergeometric test, or "binomial" for using binomial test. Fisher's exact test is to test the independence between gene group (genes belonging to a group or not) and gene annotation (genes annotated by a term or not), and thus compare sampling to the left part of background (after sampling without replacement). Hypergeometric test is to sample at random (without replacement) from the background containing annotated and non-annotated genes, and thus compare sampling to background. Unlike hypergeometric test, binomial test is to sample at random (with replacement) from the background with the constant probability. In terms of the ease of finding the significance, they are in order: hypergeometric test > fisher's exact test > binomial test. In other words, in terms of the calculated p-value, hypergeometric test < fisher's exact test < binomial test
 #' @param p.adjust.method the method used to adjust p-values. It can be one of "BH", "BY", "bonferroni", "holm", "hochberg" and "hommel". The first two methods "BH" (widely used) and "BY" control the false discovery rate (FDR: the expected proportion of false discoveries amongst the rejected hypotheses); the last four methods "bonferroni", "holm", "hochberg" and "hommel" are designed to give strong control of the family-wise error rate (FWER). Notes: FDR is a less stringent condition than FWER
 #' @param ontology.algorithm the algorithm used to account for the hierarchy of the ontology. It can be one of "none", "pc", "elim" and "lea". For details, please see 'Note' below
 #' @param elim.pvalue the parameter only used when "ontology.algorithm" is "elim". It is used to control how to declare a signficantly enriched term (and subsequently all genes in this term are eliminated from all its ancestors)
@@ -765,17 +765,18 @@ xEnricher <- function(data, annotation, g, background=NULL, size.range=c(10,2000
     
     ################################
     cross <- matrix(0, nrow=length(overlaps), ncol=length(overlaps))
-    for(i in seq(1,length(overlaps)-1)){
-    	x1 <- overlaps[[i]]
-    	for(j in seq(i+1,length(overlaps))){
-    		x2 <- overlaps[[j]]
-    		cross[i,j] <- length(intersect(x1, x2))
-    		cross[j,i] <- length(intersect(x1, x2))
-    	}
+    if(length(overlaps)>=2){
+		for(i in seq(1,length(overlaps)-1)){
+			x1 <- overlaps[[i]]
+			for(j in seq(i+1,length(overlaps))){
+				x2 <- overlaps[[j]]
+				cross[i,j] <- length(intersect(x1, x2))
+				cross[j,i] <- length(intersect(x1, x2))
+			}
+		}
+		colnames(cross) <- rownames(cross) <- names(overlaps)
+		diag(cross) <- sapply(overlaps, length)
     }
-    colnames(cross) <- rownames(cross) <- names(overlaps)
-    diag(cross) <- sapply(overlaps, length)
-    
     ####################################################################################
     
     eTerm <- list(term_info	 = set_info,
